==> quidproquo-actionprocessor-awslambda-0.0.224.tgz: package/lib/esm/getActionProcessor/core/event/eventBridgeEvent/deployStack/getEventGetRecordsActionProcessor.js <==
import { EventActionType, actionResult, DeployEventType, DeployEventStatusType, } from 'quidproquo-core';
import { getApiStackName, getWebStackName } from '../../../../../awsNamingUtils';
const deployTypeMap = {
    UPDATE_COMPLETE: DeployEventStatusType.Update,
    CREATE_COMPLETE: DeployEventStatusType.Create,
    DELETE_COMPLETE: DeployEventStatusType.Delete,
};
const getProcessGetRecords = (qpqConfig) => {
    return async ({ eventParams: [eventBridgeEvent, context] }) => {
        const status = eventBridgeEvent.detail['status-details'].status || '';
        const stackId = eventBridgeEvent.detail['stack-id'];
        const regex = /:stack\/([^\/]+)/;
        const match = stackId.match(regex);
        const stackName = match && match[1] ? match[1] : '';
        const internalEventRecord = {
            deployEventType: DeployEventType.Unknown,
            deployEventStatusType: deployTypeMap[status] || DeployEventStatusType.Unknown,
        };
        if (stackName === getApiStackName(qpqConfig)) {
            internalEventRecord.deployEventType = DeployEventType.Api;
        }
        else if (stackName === getWebStackName(qpqConfig)) {
            internalEventRecord.deployEventType = DeployEventType.Web;
        }
        console.log('internalEventRecord', internalEventRecord);
        return actionResult([internalEventRecord]);
    };
};
export const getEventGetRecordsActionProcessor = async (qpqConfig) => ({
    [EventActionType.GetRecords]: getProcessGetRecords(qpqConfig),
});

==> quidproquo-actionprocessor-awslambda-0.0.242.tgz: package/lib/esm/getActionProcessor/core/event/eventBridgeEvent/deployStack/getEventGetRecordsActionProcessor.js <==
import { actionResult, DeployEventStatusType, DeployEventType, EventActionType, } from 'quidproquo-core';
import { getApiStackName, getWebStackName } from '../../../../../awsNamingUtils';
const deployTypeMap = {
    UPDATE_COMPLETE: DeployEventStatusType.Update,
    CREATE_COMPLETE: DeployEventStatusType.Create,
    DELETE_COMPLETE: DeployEventStatusType.Delete,
};
const getProcessGetRecords = (qpqConfig) => {
    return async ({ eventParams: [eventBridgeEvent, context] }) => {
        const status = eventBridgeEvent.detail['status-details'].status || '';
        const stackId = eventBridgeEvent.detail['stack-id'];
        const regex = /:stack\/([^/]+)/;
        const match = stackId.match(regex);
        const stackName = match && match[1] ? match[1] : '';
        const internalEventRecord = {
            deployEventType: DeployEventType.Unknown,
            deployEventStatusType: deployTypeMap[status] || DeployEventStatusType.Unknown,
        };
        if (stackName === getApiStackName(qpqConfig)) {
            internalEventRecord.deployEventType = DeployEventType.Api;
        }
        else if (stackName === getWebStackName(qpqConfig)) {
            internalEventRecord.deployEventType = DeployEventType.Web;
        }
        console.log('internalEventRecord', internalEventRecord);
        return actionResult([internalEventRecord]);
    };
};
export const getEventGetRecordsActionProcessor = async (qpqConfig) => ({
    [EventActionType.GetRecords]: getProcessGetRecords(qpqConfig),
});
